(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/common')) :
	typeof define === 'function' && define.amd ? define(['exports', '@angular/core', '@angular/common'], factory) :
	(factory((global.ng = global.ng || {}, global.ng['angular-passchecker'] = {}),global.ng.core,global.ng.common));
}(this, (function (exports,core,common) { 'use strict';

var defaultConfig = {
    weightOfCharacters: {
        e: 0.87298,
        t: 0.90944,
        a: 0.91833,
        o: 0.92493,
        i: 0.93034,
        n: 0.93251,
        s: 0.93673,
        h: 0.93906,
        r: 0.94013,
        d: 0.95747,
        l: 0.95975,
        c: 0.97218,
        u: 0.97242,
        m: 0.97594,
        w: 0.97640,
        f: 0.97772,
        g: 0.97985,
        y: 0.98026,
        p: 0.98071,
        b: 0.98508,
        v: 0.99022,
        k: 0.99228,
        j: 0.99847,
        x: 0.99850,
        q: 0.99905,
        z: 0.99926,
        E: 0.87298,
        T: 0.90944,
        A: 0.91833,
        O: 0.92493,
        I: 0.93034,
        N: 0.93251,
        S: 0.93673,
        H: 0.93906,
        R: 0.94013,
        D: 0.95747,
        L: 0.95975,
        C: 0.97218,
        U: 0.97242,
        M: 0.97594,
        W: 0.97640,
        F: 0.97772,
        G: 0.97985,
        Y: 0.98026,
        P: 0.98071,
        B: 0.98508,
        V: 0.99022,
        K: 0.99228,
        J: 0.99847,
        X: 0.99850,
        Q: 0.99905,
        Z: 0.99926,
        1: 0.98700,
        2: 0.98600,
        3: 0.98500,
        4: 0.98400,
        5: 0.98300,
        6: 0.98200,
        7: 0.98100,
        8: 0.98000,
        9: 0.97900,
        0: 0.97800,
    },
    characterSequence: 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890',
    strengthRange: { start: 6.0, end: 10.0 } // strengthRange start and end
};

var PassChecker = /** @class */ (function () {
    function PassChecker() {
        this.defaultConfig = defaultConfig;
    }
    PassChecker.prototype.getStrength = function (password) {
        var _this = this;
        var strengthRange = [0, 0]; // [strength, strengthPercent]
        var sumRuneOccurrences = {};
        Array.from(password).forEach(function (char, index) {
            // default value
            var charValue = 1.0;
            // get rune value by frequency in language
            var characterweight = _this.defaultConfig.weightOfCharacters[char];
            if (characterweight) {
                charValue = characterweight;
            }
            
            // penalty for char sequencing
            if (index > 0) {
                if (_this.defaultConfig.characterSequence.includes(password.slice(0, index))) {
                    charValue -= (charValue / 4.0);
                }
            }
            // registry number of rune occurrence
            sumRuneOccurrences[char] = (sumRuneOccurrences[char]) ? sumRuneOccurrences[char] + 1 : 1;
            // compute rune value
            strengthRange[0] += (charValue / sumRuneOccurrences[char]);
        });
        if (strengthRange[0] > this.defaultConfig.strengthRange.start
            && strengthRange[0] < this.defaultConfig.strengthRange.end) {
            strengthRange[1] = (strengthRange[0] - this.defaultConfig.strengthRange.start) * (100.0) /
                (this.defaultConfig.strengthRange.end - this.defaultConfig.strengthRange.start);
        }
        if (strengthRange[0] > this.defaultConfig.strengthRange.end) {
            strengthRange[1] = 100.0;
        }
        return strengthRange;
    };
    return PassChecker;
}());

var AngularPasscheckerPipe = /** @class */ (function () {
    function AngularPasscheckerPipe() {
        this.passChecker = new PassChecker();
    }
    AngularPasscheckerPipe.prototype.transform = function (value, arg) {
        var result = '';
        (arg === 'percent') ? result = this.passChecker.getStrength(value)[1].toFixed(0) : '';
        (arg === 'strength') ? result = this.passChecker.getStrength(value)[0].toFixed(2) : '';
        return result;
    };
    AngularPasscheckerPipe.decorators = [
        { type: core.Pipe, args: [{
                    name: 'passchecker'
                },] },
    ];
    /** @nocollapse */
    AngularPasscheckerPipe.ctorParameters = function () { return []; };
    return AngularPasscheckerPipe;
}());

var AngularPasscheckerModule = /** @class */ (function () {
    function AngularPasscheckerModule() {
    }
    AngularPasscheckerModule.decorators = [
        { type: core.NgModule, args: [{
                    imports: [
                        common.CommonModule
                    ],
                    declarations: [
                        AngularPasscheckerPipe
                    ],
                    exports: [
                        AngularPasscheckerPipe
                    ]
                },] },
    ];
    /** @nocollapse */
    AngularPasscheckerModule.ctorParameters = function () { return []; };
    return AngularPasscheckerModule;
}());

exports.AngularPasscheckerModule = AngularPasscheckerModule;
exports.AngularPasscheckerPipe = AngularPasscheckerPipe;

Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=angular-passchecker.umd.js.map
